@@ -129,34 +129,36 @@ around run => sub ( $orig, $self, $req ) {
         'Ext.ux'        => '/static/ext/ux/',
     };
 
-    $self->{app}->{api}->{map}->extdirect_map(
-        $req->{host},
-        undef, undef,
-        sub ($api_map) {
-            my $ext_app = $Pcore::Ext::CFG->{app}->{ $self->{ext_app} };
+    my $ext_app = $Pcore::Ext::CFG->{app}->{ $self->{ext_app} };
 
-            my $data = {
-                INDEX => {    #
-                    title => $self->ext_app_title
-                },
-                resources => $resources,
-                ext       => {
-                    api_map => $api_map ? to_json($api_map)->$* : undef,
-                    loader_path    => to_json( $loader_path, readable => $self->{app}->{devel} )->$*,
-                    app_namespace  => $Pcore::Ext::NS,
-                    viewport_class => $ext_app->{viewport},
-                    overrides      => $overrides,
-                    static_classes => !$self->{app}->{devel} ? $ext_app->{js}->$* : undef,
-                },
-            };
+    my $api_map = {
+        id        => undef,
+        namespace => 'API.' . ref( $self->{app} ) =~ s[::][]smgr,
+        timeout   => undef,
+        url       => $self->{app}->{router}->get_host_api_path( $req->{host} ),
+        type      => 'remoting',
+        version   => undef,
+        actions   => $ext_app->{api},
+    };
 
-            $self->{cache} = P->tmpl->render( 'ext/index.html', $data );
+    my $data = {
+        INDEX => {    #
+            title => $self->ext_app_title
+        },
+        resources => $resources,
+        ext       => {
+            api_map        => to_json($api_map)->$*,
+            loader_path    => to_json( $loader_path, readable => $self->{app}->{devel} )->$*,
+            app_namespace  => $Pcore::Ext::NS,
+            viewport_class => $ext_app->{viewport},
+            overrides      => $overrides,
+            static_classes => !$self->{app}->{devel} ? $ext_app->{js}->$* : undef,
+        },
+    };
 
-            $req->( 200, [ 'Content-Type' => 'text/html; charset=UTF-8' ], $self->{cache} )->finish;
+    $self->{cache} = P->tmpl->render( 'ext/index.html', $data );
 
-            return;
-        }
-    );
+    $req->( 200, [ 'Content-Type' => 'text/html; charset=UTF-8' ], $self->{cache} )->finish;
 
     return;
 };
