@@ -1,4 +1,4 @@
-package Pcore::Ext v0.5.0;
+package Pcore::Ext v0.6.0;
 
 use Pcore -dist, -const;
 use Pcore::Ext::Context;
@@ -204,49 +204,59 @@ sub SCAN ( $self, $app, $ext, $framework ) {
         }
     }
 
-    # build ext apps content
-    if ( !$app->{devel} ) {
-        for my $ext_app ( values $CFG->{app}->%* ) {
-            my ( %processed_class, @app_js );
+    # build ext apps
+    for my $ext_app ( values $CFG->{app}->%* ) {
+        my $added_methods;
 
-            # topologically sort deps tree
-            my $add_deps = sub ($class_name) {
-                if ( !exists $processed_class{$class_name} ) {
-                    $processed_class{$class_name} = 1;                               # mark node as "gray"
-                }
-                elsif ( $processed_class{$class_name} == 1 ) {
-                    die q[Cyclic dependency found];                                  # entered to the "gray" node, this is cyclic deps
-                }
-                else {
-                    return;                                                          # entered to the "black" node
-                }
+        # build app content
+        my ( %processed_class, @app_js );
 
-                my $class_cfg = $CFG->{class}->{$class_name};
-
-                for my $require ( keys $class_cfg->{requires}->%* ) {
-                    next if !exists $CFG->{class}->{$require};                       # skip external deps
-
-                    __SUB__->($require);
-                }
-
-                # all deps processed
-                $processed_class{$class_name} = 2;                                   # mark node as "black"
-
-                # add content
-                push @app_js, $class_cfg->{js}->$*;
-
-                return;
-            };
-
-            # start sorting deps
-            for my $class ( values $CFG->{class}->%* ) {
-                next if $class->{app_namespace} // $class->{namespace} ne $ext_app->{namespace};
-
-                $add_deps->( $class->{class} );
+        # topologically sort deps tree
+        my $add_deps = sub ($class_name) {
+            if ( !exists $processed_class{$class_name} ) {
+                $processed_class{$class_name} = 1;    # mark node as "gray"
+            }
+            elsif ( $processed_class{$class_name} == 1 ) {
+                die q[Cyclic dependency found];       # entered to the "gray" node, this is cyclic deps
+            }
+            else {
+                return;                               # entered to the "black" node
             }
 
-            $ext_app->{js} = \join ';', @app_js;
+            my $class_cfg = $CFG->{class}->{$class_name};
+
+            for my $require ( keys $class_cfg->{requires}->%* ) {
+                next if !exists $CFG->{class}->{$require};    # skip external deps
+
+                __SUB__->($require);
+            }
+
+            # all deps processed
+            $processed_class{$class_name} = 2;                # mark node as "black"
+
+            # add content
+            push @app_js, $class_cfg->{js}->$* if !$app->{devel};
+
+            # add api map
+            for my $method_id ( keys $class_cfg->{api}->%* ) {
+                next if exists $added_methods->{$method_id};
+
+                $added_methods->{$method_id} = undef;
+
+                push $ext_app->{api}->{ delete $class_cfg->{api}->{$method_id}->{action} }->@*, $class_cfg->{api}->{$method_id};
+            }
+
+            return;
+        };
+
+        # start sorting deps
+        for my $class ( values $CFG->{class}->%* ) {
+            next if $class->{app_namespace} // $class->{namespace} ne $ext_app->{namespace};
+
+            $add_deps->( $class->{class} );
         }
+
+        $ext_app->{js} = \join ';', @app_js if !$app->{devel};
     }
 
     return;
@@ -267,7 +277,7 @@ sub _get_ctx ( $self, $class, $app, $framework ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 20                   | Subroutines::ProhibitExcessComplexity - Subroutine "SCAN" with high complexity score (36)                      |
+## |    3 | 20                   | Subroutines::ProhibitExcessComplexity - Subroutine "SCAN" with high complexity score (39)                      |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
