@@ -97,7 +97,27 @@ sub ext_api_method ( $self, $method_id ) {
 
     my $method = $map->get_method($method_id) // die qq[API method "$method_id" is not exists in "$self->{ctx}->{namespace}::$self->{ctx}->{generator}"];
 
-    return "$map->{extjs_namespace}.$method->{extjs_action}.$method->{method_name}";
+    my $ext_api_namespace = 'API.' . ref( $self->{app} ) =~ s[::][]smgr;
+
+    my $ext_api_action = $method->{class_path} =~ s[/][.]smgr =~ s[\A[.]][]smr;
+
+    if ( !exists $self->{ctx}->{api}->{ $method->{id} } ) {
+        $self->{ctx}->{api}->{ $method->{id} } = {
+            action   => $ext_api_action,
+            name     => $method->{method_name},
+            len      => 1,
+            params   => [],
+            strict   => \0,
+            metadata => {
+                len    => 1,
+                params => [],
+                strict => \0,
+            },
+            formHandler => \0,
+        };
+    }
+
+    return "$ext_api_namespace.$ext_api_action.$method->{method_name}";
 }
 
 sub get_class ( $self, $name ) {
